The application collects information about users' sexual orientation, but the privacy policy does not disclose this. Sexual orientation is a special category of personal information under regulations like GDPR and is highly sensitive. Failure to inform users about this collection is a very serious issue and likely violates legal requirements for explicit consent and the most stringent data protection measures.